@@ -31,6 +31,7 @@
 #include "jit/emit-code.h"
 #include "jit/statement.h"
 #include "jit/compiler.h"
+#include "jit/vars.h"
 
 #include "vm/method.h"
 #include "vm/die.h"
@@ -58,7 +59,7 @@ static inline int print_reg(struct string *str, struct operand *op)
 {
 	struct live_interval *interval = op->reg.interval;
 
-	if (interval->fixed_reg)
+	if (interval_has_fixed_reg(interval))
 		return str_append(str, "r%lu=%s", interval->var_info->vreg,
 				  reg_name(interval->reg));
 	else
@@ -118,9 +119,9 @@ static int print_imm_memlocal(struct string *str, struct insn *insn)
 
 static int print_imm_memdisp(struct string *str, struct insn *insn)
 {
-	print_imm(str, &insn->operands[0]);
+	print_imm(str, &insn->src);
 	str_append(str, ", ");
-	return print_memdisp(str, &insn->operands[1]);
+	return print_memdisp(str, &insn->dest);
 }
 
 static int print_membase_reg(struct string *str, struct insn *insn)
@@ -417,7 +418,7 @@ static int print_call_reg(struct string *str, struct insn *insn)
 {
 	print_func_name(str);
 	str_append(str, "(");
-	print_reg(str, &insn->operand);
+	print_reg(str, &insn->dest);
 	return str_append(str, ")");
 }
 
@@ -673,12 +674,6 @@ static int print_mov_imm_tlmembase(struct string *str, struct insn *insn)
 	return print_imm_tlmembase(str, insn);
 }
 
-static int print_mov_ip_tlmembase(struct string *str, struct insn *insn)
-{
-	print_func_name(str);
-	return print_tlmembase(str, &insn->operands[0]);
-}
-
 static int print_mov_reg_tlmembase(struct string *str, struct insn *insn)
 {
 	print_func_name(str);
@@ -805,7 +800,7 @@ static int print_mul_reg_reg(struct string *str, struct insn *insn)
 static int print_neg_reg(struct string *str, struct insn *insn)
 {
 	print_func_name(str);
-	return print_reg(str, &insn->operand);
+	return print_reg(str, &insn->dest);
 }
 
 static int print_or_imm_membase(struct string *str, struct insn *insn)
@@ -838,12 +833,6 @@ static int print_push_reg(struct string *str, struct insn *insn)
 	return print_reg(str, &insn->operand);
 }
 
-static int print_push_membase(struct string *str, struct insn *insn)
-{
-	print_func_name(str);
-	return print_membase(str, &insn->operand);
-}
-
 static int print_push_memlocal(struct string *str, struct insn *insn)
 {
 	print_func_name(str);
@@ -945,12 +934,6 @@ static int print_xor_membase_reg(struct string *str, struct insn *insn)
 	return print_membase_reg(str, insn);
 }
 
-static int print_xor_imm_reg(struct string *str, struct insn *insn)
-{
-	print_func_name(str);
-	return print_imm_reg(str, insn);
-}
-
 static int print_xor_reg_reg(struct string *str, struct insn *insn)
 {
 	print_func_name(str);
@@ -1033,7 +1016,6 @@ static print_insn_fn insn_printers[] = {
 	[INSN_MOV_IMM_MEMLOCAL] = print_mov_imm_memlocal,
 	[INSN_MOV_IMM_REG] = print_mov_imm_reg,
 	[INSN_MOV_IMM_THREAD_LOCAL_MEMBASE] = print_mov_imm_tlmembase,
-	[INSN_MOV_IP_THREAD_LOCAL_MEMBASE] = print_mov_ip_tlmembase,
 	[INSN_MOV_MEMLOCAL_REG] = print_mov_memlocal_reg,
 	[INSN_MOV_MEMLOCAL_XMM] = print_mov_memlocal_xmm,
 	[INSN_MOV_64_MEMLOCAL_XMM] = print_mov_64_memlocal_xmm,
@@ -1072,7 +1054,6 @@ static print_insn_fn insn_printers[] = {
 	[INSN_OR_REG_REG] = print_or_reg_reg,
 	[INSN_PUSH_IMM] = print_push_imm,
 	[INSN_PUSH_REG] = print_push_reg,
-	[INSN_PUSH_MEMBASE] = print_push_membase,
 	[INSN_PUSH_MEMLOCAL] = print_push_memlocal,
 	[INSN_POP_MEMLOCAL] = print_pop_memlocal,
 	[INSN_POP_REG] = print_pop_reg,
@@ -1090,7 +1071,6 @@ static print_insn_fn insn_printers[] = {
 	[INSN_TEST_IMM_MEMDISP] = print_test_imm_memdisp,
 	[INSN_TEST_MEMBASE_REG] = print_test_membase_reg,
 	[INSN_XOR_MEMBASE_REG] = print_xor_membase_reg,
-	[INSN_XOR_IMM_REG] = print_xor_imm_reg,
 	[INSN_XOR_REG_REG] = print_xor_reg_reg,
 	[INSN_XOR_XMM_REG_REG] = print_xor_xmm_reg_reg,
 	[INSN_XOR_64_XMM_REG_REG] = print_xor_64_xmm_reg_reg,
