@@ -36,6 +36,7 @@ struct basic_block {
 	unsigned long nr_mimic_stack_expr;
 	struct expression **mimic_stack_expr;
 	unsigned long mach_offset;
+	int dfn;
 
 	/* Contains data flow resultion blocks for each outgoing CFG edge. */
 	struct resolution_block *resolution_blocks;
@@ -53,6 +54,13 @@ struct basic_block {
 	/* Is this basic block an exception handler? */
 	bool is_eh;
 
+	/*
+	 * These are computed by SSA.
+	 */
+	struct {
+		struct bitset *dom_frontier;
+	};
+
 	/*
 	 * These are computed by liveness analysis.
 	 */
@@ -84,6 +92,7 @@ static inline bool bb_mimic_stack_is_resolved(struct basic_block *bb)
 }
 
 struct basic_block *alloc_basic_block(struct compilation_unit *, unsigned long, unsigned long);
+struct basic_block *do_alloc_basic_block(struct compilation_unit *, unsigned long, unsigned long);
 struct basic_block *get_basic_block(struct compilation_unit *, unsigned long, unsigned long);
 void shrink_basic_block(struct basic_block *);
 void free_basic_block(struct basic_block *);
